import { CounterControls } from './useCounter';
export interface ClockOptions<T> {
    locales?: string | string[];
    dateTimeFormatOptions?: Intl.DateTimeFormatOptions;
    customFormatter?: (date: Date) => T;
    startTimeInMilliseconds?: number;
    keepPausedClockRunningInBackground?: boolean;
}
/**
 * Creates a sort of clock, i.e. a reactive time-based value that updates every second.
 * useClock is generic (by default useClock<string> is used). The generic type defines the return type which can be
 * changed by using a custom formatter (see options.customFormatter).
 *
 * @template [T=string]
 * @param options options.locales and options.dateTimeFormatOptions will be directly forwarded to date.toLocaleTimeString().
 *                You can also use options.customFormatter to override the output of the hook. The output must match the generic type of the hook.
 *                options.keepPausedClockRunningInBackground will allow to only pause the output but not the underlying clock, so that it resumes at the correct time.
 * @returns The current (formatted) time
 */
declare const useClock: <T = string>(options?: ClockOptions<T>) => [T, CounterControls];
export default useClock;
