import { IntervalControls, IntervalOptions } from './useInterval';
export type OscillatorSettings = IntervalOptions & {
    /** the initial boolean value (i.e. either true or false) */
    initialValue: boolean;
    /** duration in ms between each boolean toggle */
    interval: number;
    /** If true, the oscillator will reset to the initial value on stop. If false, it won't. */
    resetOnStop?: boolean;
    /** If true, the interval in the background will be destroyed upon pause. If false, it won't. */
    destroyIntervalOnPause?: boolean;
};
export type OscillatorControls = IntervalControls & {
    /** Will reset the current value to the initial value */
    reset(): void;
};
/**
 * A hook creates an oscillating boolean value,
 * i.e. a value that automatically toggles repeatedly (infinitely switching from true to false and back) at a fixed interval.
 *
 * Active intervals will be cleared on unmount.
 *
 * @param settings Oscillator settings and interval options
 */
declare const useOscillator: (settings: OscillatorSettings) => [boolean, OscillatorControls];
export default useOscillator;
