export type ThrottleOptions = {
    leading?: boolean;
    trailing?: boolean;
};
/**
 * Throttles a callback.
 *
 * Can be used for **rate-limiting** – the callback will only be invoked every X milliseconds (X being the set timeout),
 * even if it was called more frequently.
 *
 * Similar, but different(!), is the `useDebounce()` hook, which blocks the invocation entirely until the function was
 * stopped being called for X milliseconds.
 *
 * By default, the throttled function will always be called immediately (`options.leading` is true by default) and then
 * (`options.trailing` is true by default) also after every X milliseconds for consecutive calls.
 *
 * @param callback
 * @param waitMs Minimum waiting time between consecutive calls
 * @param options
 * @param [options.leading = true] If true, invoke the callback immediately/before the timeout
 * @param [options.trailing = true] If true, queue invocations to be called after the timeout
 */
export declare function useThrottle<T extends (...args: never[]) => unknown>(callback: T, waitMs: number, options?: ThrottleOptions): (...args: Parameters<T>) => NodeJS.Timeout | number;
