/**
 * This hook will return a function that executes the provided callback after the specified amount of time.
 *
 * This **will not debounce or throttle** the callbacks, i.e. consecutive calls of this function will all spawn
 * new timeouts even if some are still pending. If you want a debouncing version, take a look at `useDebounce()`.
 * If you want a throttling version, see `useThrottle()`.
 *
 * Pending callbacks will only(!) be cleared in case the component unmounts.
 *
 * @param callback The callback that is invoked after the timeout expired
 * @param waitMs The timeout in milliseconds
 *
 * @returns a function that executes the provided callback after the specified amount of time
 */
declare function useTimeout<T extends (...args: never[]) => unknown>(callback: T, waitMs: number): (...args: Parameters<T>) => NodeJS.Timeout | number;
export default useTimeout;
