import { DependencyList } from 'react';
import { TimeoutEffectCallback } from './types';
/**
 * This hook behaves like a regular useEffect except that it provides a timeout function via it's arguments
 * that can be used to spawn timeouts via `window.setTimeout()` from inside the effect. The timeouts will be cleared on unmount.
 * @param effect The effect callback, it receives a timeout function as its first argument and a timeout clearer as its second
 * @param deps The dependency array from useEffect.
 */
declare const useTimeoutEffect: (effect: TimeoutEffectCallback, deps: DependencyList) => void;
export default useTimeoutEffect;
